==> nomachine-7.8.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXBroadcast.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXBroadcast::sendMessage{package NXBroadcast;no warnings;(my $ref_parameters
=shift (@_));if (($$ref_parameters{"\x6d\x65\x73\x73\x61\x67\x65"}eq (""))){
NXMsg::error ("\x65\x4d\x65\x73\x73\x61\x67\x65\x45\x6d\x70\x74\x79",
"\x4e\x58\x53\x68\x65\x6c\x6c");return ((0x053f+ 2257-0x0e10));}my ($host,$port)
;if (($$ref_parameters{"\x6e\x6f\x64\x65"}ne (""))){main::nxrequire (
"\x4e\x58\x4e\x6f\x64\x65\x73");(($host,$port)=NXNodes::getNodeHostAndPort (
$$ref_parameters{"\x6e\x6f\x64\x65"}));if (NXNodes::isErrorNotExistInDatabase (
$port)){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});return ((0x04d3+ 848-0x0823));}elsif (
NXNodes::isErrorMoreThenOneHost ($port)){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x50\x6f\x72\x74\x4d\x69\x73\x73\x69\x6e\x67"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74");return ((0x1442+ 2275-0x1d25));
}(my $nodeCheck=NXNodes::checkNodeExist ($host,$port));if ((not (($nodeCheck=~ /^exist$/ )
))){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});return ((0x083f+ 1899-0x0faa));}NXMsg::send_response (
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x54\x6f\x4e\x6f\x64\x65"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},$$ref_parameters{"\x6e\x6f\x64\x65"});}else{
NXMsg::send_response (
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"});}(my (@sessionIds)=
NXSession2::listSessionsForBroadcast ($host,$port));sub BEGIN{require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}foreach my $id (
@sessionIds){&try (sub{NXShell::send_message_to_session ($id,$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},"\x62\x72\x6f\x61\x64\x63\x61\x73\x74");},
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x66\x6f\x4d\x61\x6e\x61\x67\x65\x72\x3a\x3a\x52\x65\x63\x6f\x72\x64\x4e\x6f\x74\x46\x6f\x75\x6e\x64"
->catch (&with (sub{NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x53\x65\x73\x73\x69\x6f\x6e"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},$id);return;})));}if (($$ref_parameters{
"\x6e\x6f\x64\x65"}ne (""))){NXMsg::info (
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b\x54\x6f\x4e\x6f\x64\x65"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});}else{NXMsg::info (
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b",
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74");}return ((0x0aa4+ 1192-0x0f4b));
}package NXBroadcast;no warnings;NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
(0x1c8c+ 1390-0x1e76));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x54\x6f\x4e\x6f\x64\x65"
,(0x0c68+ 6713-0x231d));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b",
(0x037c+ 3935-0x125d));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b\x54\x6f\x4e\x6f\x64\x65"
,(0x08f1+ 4385-0x1994));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,(0x0505+ 250-0x040b));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x50\x6f\x72\x74\x4d\x69\x73\x73\x69\x6e\x67"
,(0x234c+ 1035-0x2563));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x53\x65\x73\x73\x69\x6f\x6e"
,(0x05c0+ 6661-0x1d7a));return ((0x1e53+ 1252-0x2336));

==> nomachine-7.9.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXBroadcast.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2022 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXBroadcast::sendMessage{package NXBroadcast;no warnings;(my $ref_parameters
=shift (@_));if (($$ref_parameters{"\x6d\x65\x73\x73\x61\x67\x65"}eq (""))){
NXMsg::error ("\x65\x4d\x65\x73\x73\x61\x67\x65\x45\x6d\x70\x74\x79",
"\x4e\x58\x53\x68\x65\x6c\x6c");return ((0x1170+ 3211-0x1dfb));}my ($host,$port)
;if (($$ref_parameters{"\x6e\x6f\x64\x65"}ne (""))){main::nxrequire (
"\x4e\x58\x4e\x6f\x64\x65\x73");(($host,$port)=NXNodes::getNodeHostAndPort (
$$ref_parameters{"\x6e\x6f\x64\x65"}));if (NXNodes::isErrorNotExistInDatabase (
$port)){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});return ((0x0093+ 4398-0x11c1));}elsif (
NXNodes::isErrorMoreThenOneHost ($port)){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x50\x6f\x72\x74\x4d\x69\x73\x73\x69\x6e\x67"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74");return ((0x1434+ 3901-0x2371));
}(my $nodeCheck=NXNodes::checkNodeExist ($host,$port));if ((not (($nodeCheck=~ /^exist$/ )
))){NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});return ((0x0c33+ 5460-0x2187));}NXMsg::send_response (
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x54\x6f\x4e\x6f\x64\x65"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},$$ref_parameters{"\x6e\x6f\x64\x65"});}else{
NXMsg::send_response (
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"});}(my (@sessionIds)=
NXSession2::listSessionsForBroadcast ($host,$port));sub BEGIN{require Error;do{
"\x45\x72\x72\x6f\x72"->import ("\x3a\x74\x72\x79")};}foreach my $id (
@sessionIds){&try (sub{NXShell::send_message_to_session ($id,$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},"\x62\x72\x6f\x61\x64\x63\x61\x73\x74");},
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x66\x6f\x4d\x61\x6e\x61\x67\x65\x72\x3a\x3a\x52\x65\x63\x6f\x72\x64\x4e\x6f\x74\x46\x6f\x75\x6e\x64"
->catch (&with (sub{NXMsg::error (
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x53\x65\x73\x73\x69\x6f\x6e"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6d\x65\x73\x73\x61\x67\x65"},$id);return;})));}if (($$ref_parameters{
"\x6e\x6f\x64\x65"}ne (""))){NXMsg::info (
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b\x54\x6f\x4e\x6f\x64\x65"
,"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",$$ref_parameters{
"\x6e\x6f\x64\x65"});}else{NXMsg::info (
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b",
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74");}return ((0x1a9d+ 2331-0x23b7));
}package NXBroadcast;no warnings;NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
(0x190a+ 3713-0x2407));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x53\x65\x6e\x64\x69\x6e\x67\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x54\x6f\x4e\x6f\x64\x65"
,(0x1592+ 3403-0x1f59));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b",
(0x0503+ 3273-0x114e));NXMsg::register_response (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x69\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4d\x65\x73\x73\x61\x67\x65\x4f\x6b\x54\x6f\x4e\x6f\x64\x65"
,(0x12ed+ 2152-0x1ad7));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x44\x6f\x65\x73\x4e\x6f\x74\x45\x78\x69\x73\x74"
,(0x1610+ 2641-0x1e6d));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x4e\x6f\x64\x65\x50\x6f\x72\x74\x4d\x69\x73\x73\x69\x6e\x67"
,(0x193d+ 2691-0x21cc));NXMsg::register_error (
"\x4e\x58\x42\x72\x6f\x61\x64\x63\x61\x73\x74",
"\x65\x43\x4d\x44\x42\x72\x6f\x61\x64\x63\x61\x73\x74\x53\x65\x73\x73\x69\x6f\x6e"
,(0x16d0+ 2215-0x1d2c));return ((0x1a28+ 1042-0x1e39));
